@@ -9,13 +9,14 @@ import json
 def create_cluster(clusterName, image=None, type=None, nodes=1, description='', user_data=None, env=None, disk=None,
                    notification_endpoint=None, notification_topic=None, notification_events=None,
                    mount=None, nas_access_group=None, nas_file_system=None, resource_type='OnDemand',
-                    vpc_cidr_block=None, filePath=None,
+                    vpc_cidr_block=None, vpc_id=None, file_path=None, schedule_type=None,
                    no_cache_support=False,
+                   spot_price_limit=None,
                    show_json=False):
     cluster_desc = {}
 
-    if filePath:
-        cluster_desc = getClusterJSON(filePath)
+    if file_path:
+        cluster_desc = getClusterJSON(file_path)
 
     else:
 
@@ -28,6 +29,9 @@ def create_cluster(clusterName, image=None, type=None, nodes=1, description='',
         cluster_desc['InstanceType'] = type
         cluster_desc['Description'] = description
 
+        if schedule_type:
+            cluster_desc['ScheduleType']=schedule_type
+
         cluster_desc['Groups']={
             'group': {
                 'InstanceType': type,
@@ -44,6 +48,16 @@ def create_cluster(clusterName, image=None, type=None, nodes=1, description='',
             #     #"VPC": {}
             # }
         }
+        if spot_price_limit is not None:
+            spot_price_limit = float(spot_price_limit)
+            if not resource_type == 'Spot':
+                raise Exception('spot_price_limit works only if resource_type is Spot')
+
+            if spot_price_limit > 0:
+                cluster_desc['Groups']['group']['SpotPriceLimit'] = spot_price_limit
+                cluster_desc['Groups']['group']['SpotStrategy'] = 'SpotWithPriceLimit'
+            else:
+                cluster_desc['Groups']['group']['SpotStrategy'] = 'SpotAsPriceGo'
 
         if user_data:
             cluster_desc['UserData'] = {}
@@ -81,6 +95,8 @@ def create_cluster(clusterName, image=None, type=None, nodes=1, description='',
             cluster_desc['Notification']['Topic']['Events'] = notification_events
 
         # vpc
+        vpc_cidr_block = vpc_cidr_block if vpc_cidr_block else config.getConfigs(config.COMMON, ['vpc_cidr_block']).get('vpc_cidr_block')
+
         if vpc_cidr_block:
             if not cluster_desc['Configs'].get('Networks'):
                 cluster_desc['Configs']['Networks']={}
@@ -88,6 +104,17 @@ def create_cluster(clusterName, image=None, type=None, nodes=1, description='',
                 cluster_desc['Configs']['Networks']['VPC']={}
             cluster_desc['Configs']['Networks']['VPC']['CidrBlock']=vpc_cidr_block
 
+
+        if vpc_id:
+            if not vpc_cidr_block:
+                raise Exception('vpc_id must works with vpc_cidr_block')
+
+            if not cluster_desc['Configs'].get('Networks'):
+                cluster_desc['Configs']['Networks']={}
+            if not cluster_desc['Configs']['Networks'].get('VPC'):
+                cluster_desc['Configs']['Networks']['VPC']={}
+            cluster_desc['Configs']['Networks']['VPC']['VpcId']=vpc_id
+
     if show_json:
         print(json.dumps(cluster_desc, indent=4))
     else:
@@ -104,12 +131,15 @@ def getClusterJSON(filePath):
     return s
 def trans_mount(s):
     return util.trans_mount(s)
-
+def trans_schedule_type(s):
+    if s not in ['LowLatency','Poll','Push']:
+        raise Exception('Invalid schedule_type')
+    return s
 
 def extend_mount(desc, mount_m):
+    desc['Configs']['Mounts']['Entries'] = []
     for k, v in mount_m.items():
         if k.startswith('oss://') or k.startswith('nas://'):
-            desc['Configs']['Mounts']['Entries'] = []
             desc['Configs']['Mounts']['Entries'].append({
                 "Destination": v,
                 "Source": k,
@@ -160,4 +190,5 @@ def trans_env(env):
     return t
 
 def trans_disk(disk):
-    return util.trans_disk(disk)
\ No newline at end of file
+    return util.trans_disk(disk)
+
