@@ -5,7 +5,7 @@ from ..util import client, result_cache,util
 from terminal import confirm,green
 import json
 
-def update(clusterId, nodes=None, groupName='group', mount=None, image=None, user_data=None, env=None, yes=False,
+def update(clusterId, nodes=None, groupName='group', mount=None, type=None, image=None, user_data=None, env=None, yes=False,
            spot_price_limit=None,
            show_json=False):
 
@@ -34,6 +34,9 @@ def update(clusterId, nodes=None, groupName='group', mount=None, image=None, use
     if image:
         desc['ImageId'] = image
 
+    if type:
+        desc['Groups'][groupName]['InstanceType'] = type
+
     if user_data:
         desc['UserData'] = {}
         for item in user_data:
