@@ -69,9 +69,16 @@ def change_cluster_vmcount(cluster_id, groupName, vmCount):
     client = _get_client()
     return client.change_cluster_desired_vm_count(cluster_id, **{groupName: int(vmCount)})
 
-def update_cluster(cluster_id, clsuterDesc):
+def update_cluster(cluster_id, clusterDesc):
     client = _get_client()
-    return client.modify_cluster(cluster_id, clsuterDesc)
+    client.modify_cluster(cluster_id, clusterDesc)
+
+    if clusterDesc.get('Groups'):
+        for (k,v) in clusterDesc['Groups'].items():
+            if v.get('SpotStrategy'):
+                client.change_cluster_spot_config(cluster_id, k, strategy=v.get('SpotStrategy'),
+                                                  price_limit=v.get('SpotPriceLimit'))
+
 
 
 def list_jobs():
@@ -170,6 +177,68 @@ def create_job(jobDesc):
     client = _get_client()
     return client.create_job(jobDesc)
 
+############################
+def list_apps():
+    client = _get_client()
+
+    sysArr = __list_apps(client, '', 100, scope='Public')
+    for n in sysArr:
+        n['Scope'] = 'Public'
+
+    arr = __list_apps(client, '', 100, scope='Private')
+    for n in arr:
+        n['Scope'] = 'Private'
+
+
+    formater.order_by(sysArr, ['CreationTime'], True)
+    formater.order_by(arr, ['CreationTime'], True)
+    return {'Items': sysArr + arr, 'Marker': ''}
+
+def __list_apps(client, marker='', maxItemCount=100, scope="Private"):
+    t = []
+    result = client.list_apps(scope, marker, maxItemCount)
+    if result.Items:
+        tt = __items2list(result.Items)
+        if scope=='Public':
+            for n in tt:
+                n['Name'] = ":%s" % n['Name']
+        t = t + tt
+
+    if result.NextMarker and result.NextMarker!='':
+        arr = __list_apps(client, result.NextMarker, maxItemCount, scope)
+        t = t + arr
+    return t
+
+def get_app(appName, scope="Private"):
+    client = _get_client()
+    info = client.get_app(appName, scope)
+    return info
+
+
+def get_app_revisions(appName):
+    client = _get_client()
+    return client.get_app_revisions(appName)
+
+
+def get_app_detail(appName, qualifier=""):
+    client = _get_client()
+    return client.get_app_detail(appName, qualifier)
+
+
+def delete_app(appName, revision):
+    client = _get_client()
+    return client.delete_app(appName, revision)
+
+def create_app(desc):
+    client = _get_client()
+    return client.create_app(desc)
+
+def update_app(appName, desc):
+    client = _get_client()
+    return client.modify_app(appName, desc)
+
+
+#############################
 def list_images():
     client = _get_client()
 
